;
Date.prototype.format = function(format) {
	var args = {
		"M+": this.getMonth() + 1,
		"d+": this.getDate(),
		"h+": this.getHours(),
		"m+": this.getMinutes(),
		"s+": this.getSeconds(),
		"q+": Math.floor((this.getMonth() + 3) / 3), //quarter
		"S": this.getMilliseconds()
	};
	if(/(y+)/.test(format))
		format = format.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
	for(var i in args) {
		var n = args[i];
		if(new RegExp("(" + i + ")").test(format))
			format = format.replace(RegExp.$1, RegExp.$1.length == 1 ? n : ("00" + n).substr(("" + n).length));
	}
	return format;
};

/**
 * 图片上传控件，需要同时引入global.js和location.js
 * @param container 上传后图片排列的容器
 * @param addSelector 点击展开上传文件选择的控件选择器
 * @param uploadModule 上传图片所属的模块名称，业务相关
 * @param ownId 上传图片所属对象的Id，比如客户Id
 * @param required 是否必须上传图片
 * @param isTextWatermark 是否添加位置水印
 * @constructor
 * 
 */
function PictureUploader(container, addSelector, uploadModule, ownId, required) {

	var pictureUploader = {};
	pictureUploader.selector = addSelector;
	pictureUploader.uploadUrl = global.service_url + "/document/upload";
	pictureUploader.uploadModule = uploadModule;
	pictureUploader.ownId = ownId;
	pictureUploader.container = container;
	pictureUploader.storageKey = addSelector.replace("#", "") + "-imgList" + (new Date()).getTime();

	pictureUploader.required = required;
	pictureUploader.isAddressWatermark = true;

	var currentAddress = global.userInfo.getAddress();
	var currentUserName = global.userInfo.getRealName();
	var time = new Date().format("yyyy-MM-dd hh:mm:ss");
	pictureUploader.watermark = currentUserName + "@" + time + "@" + currentAddress;

	pictureUploader.init = function() {
		plus.storage.removeItem(pictureUploader.storageKey);
		pictureUploader.clear();
		//      alert(this.selector);
		document.body.querySelector(this.selector).addEventListener("tap", function() {
			var actionbuttons = [{
				title: "拍照"
			}, {
				title: "相册选取"
			}];
			var actionstyle = {
				title: "选择照片",
				cancel: "取消",
				buttons: actionbuttons
			};
			plus.nativeUI.actionSheet(actionstyle, function(e) {
				if(e.index == 1) {
					pictureUploader.getImage();
				} else if(e.index == 2) {
					pictureUploader.galleryImg();
				}
			});
		});

		mui("body").on("tap", ".del", function() {
			var imgId = this.id;
			if(imgId) {
				imgId = imgId.replace("del_", "");
				pictureUploader.delImg(imgId);
			}

		});

	};

	/**
	 * 相册选取
	 * @param divid
	 */
	pictureUploader.galleryImg = function() {
		plus.gallery.pick(function(e) {
			var zm = 0;
			setTimeout(readFile, 200);

			function readFile() {
				plus.io.resolveLocalFileSystemURL(e.files[zm], function(entry) {
					pictureUploader.compressImage(entry.toLocalURL(), entry.name);
				}, function(e) {
					plus.nativeUI.toast("读取拍照文件错误：" + e.message);
				});
				zm++;
				if(zm < e.files.length) {
					setTimeout(readFile, 200);
				}
			}

		}, function(e) {
			// console.log("取消选择图片");
		}, {
			filename: "_doc/camera/",
			// filter: "image",
			filter: "none", //不过滤，可选择图片或视频文件
			multiple: true,
			maximum: 3,
			system: false,
			onmaxed: function() {
				plus.nativeUI.alert('一次最多只能选择3张图片');
			}
		});
	};

	/**
	 * 拍照
	 * @param divid
	 */
	pictureUploader.getImage = function() {
		var cmr = plus.camera.getCamera();
		cmr.captureImage(function(p) {
			//alert(p);//_doc/camera/1467602809090.jpg
			plus.io.resolveLocalFileSystemURL(p, function(entry) {
				// alert(entry.toLocalURL());
				// file:///storage/emulated/0/Android/data/io.dcloud...../doc/camera/1467602809090.jpg
				// alert(entry.name);
				// 1467602809090.jpg
				pictureUploader.compressImage(entry.toLocalURL(), entry.name);
			}, function(e) {
				plus.nativeUI.toast("读取拍照文件错误：" + e.message);
			});
		}, function(e) {}, {
			filename: "_doc/camera/",
			index: 1
		});
	};

	//压缩图片
	pictureUploader.compressImage = function(url, filename) {
		filename = filename.replace(/[&\|\\\*^%$#@\-=?,？]/g, "");

		var name = "_doc/upload/" + pictureUploader.selector.replace("#", "") + "-" + filename; //_doc/upload/F_ZDDZZ-1467602809090.jpg
		plus.zip.compressImage({
				src: url, //src: (String 类型 )压缩转换原始图片的路径
				dst: name, //压缩转换目标图片的路径
				quality: 70, //quality: (Number 类型 )压缩图片的质量.取值范围为1-100
				overwrite: true //overwrite: (Boolean 类型 )覆盖生成新文件
			},
			function(event) {
				//uploadf(event.target,divid);
				var path = name; //压缩转换目标图片的路径
				//event.target获取压缩转换后的图片url路
				pictureUploader.saveImage(event.target, filename, path);
			},
			function(error) {
				plus.nativeUI.toast("压缩图片失败，请稍候再试：" + error.message);
			});

	};

	/**
	 * 保存信息到本地
	 * @param {Object} url  图片的地址
	 * @param {Object} divid  字段的名称
	 * @param {Object} fileName   图片的名称
	 */
	pictureUploader.saveImage = function(url, fileName, path) {

		//图片打水印
//		var img = new Image();
//		img.src = url;
//		img.onload = function() {
//			var width = img.width;
//			var height = img.height;
//			var canvas = document.createElement('canvas');
//			canvas.id = fileName + '_canvas';
//			canvas.width = width;
//			canvas.height = height;
//			var ctx = canvas.getContext('2d');
//			ctx.drawImage(this, 0, 0, width, height);
//			ctx.font = "microsoft yahei";
//			ctx.fillStyle = "rgba(17, 17, 17, 0.50)";
//			ctx.textAlign = 'left';
//			ctx.textBaseline = 'Middle';
//			ctx.fillText("中国您好", width / 3, height / 2);
//
//			alert("old url:" + url);
//			url = canvas.toDataURL("image/png", 0.9);
//			alert("new url:" + url);
//		}

		// alert(url);
		// file:///storage/emulated/0/Android/data/io.dcloud...../doc/upload/F_ZDDZZ-1467602809090.jpg
		// alert(path);
		// _doc/upload/F_ZDDZZ-1467602809090.jpg
		var state = 0;
		var wt = plus.nativeUI.showWaiting();
		//  plus.storage.clear();
		fileName = "img" + fileName.substring(0, fileName.indexOf(".")); //图片名称：1467602809090

		// var id = document.getElementById("ckjl.id").value;
		var storageKey = pictureUploader.storageKey;
		var storageValue = plus.storage.getItem(storageKey);
		var imgList;
		if(storageValue == null) {
			var imgList = [];
		} else {
			imgList = JSON.parse(storageValue);
		}
		var imgJson = {
			fileName: fileName,
			path: path,
			url: url
		};
		imgList.push(imgJson);
		storageValue = JSON.stringify(imgList);
		plus.storage.setItem(storageKey, storageValue);
		// console.log("已经选择的图片：" + storageValue);

		pictureUploader.showImgDetail(fileName, 'src="' + url + '"');

		wt.close();

	};

	pictureUploader.showImgDetail = function(fileName, src) {

		var html = "";
		html += '<div  id="' + fileName + '" class="image-item ">';
		html += '    <img id="picBig" data-preview-src="" data-preview-group="1" ' + src + '/>';
		html += '    <span class="del" id="del_' + fileName + '">';
		html += '        <div class="fa fa-times-circle">X</div>';
		html += '    </span>';
		html += '</div>';

		var dom = document.createElement("div");
		dom.innerHTML = html;

		var targetDom = document.querySelector(pictureUploader.container);
		targetDom.appendChild(dom);
		// console.log(dom.innerHTML);
	};

	pictureUploader.clear = function() {
		var storageValue = plus.storage.getItem(pictureUploader.storageKey);
		if(!storageValue || storageValue.length == 0) return;

		var imgList = JSON.parse(storageValue);

		if(imgList && imgList.length > 0) {
			for(var i = 0; i < imgList.length; i++) {
				var imgId = imgList[i].fileName;
				pictureUploader.delFromImg(imgId);
			}
			plus.storage.removeItem(pictureUploader.storageKey);
		}
	};

	pictureUploader.delImg = function(imgId) {
		var bts = ["是", "否"];
		plus.nativeUI.confirm("是否删除图片？", function(e) {
			var i = e.index;
			if(i == 0) {
				var storageValue = plus.storage.getItem(pictureUploader.storageKey);

				if(!storageValue || storageValue.length == 0) {
					pictureUploader.delFromImg(imgId);
				} else {
					var index = storageValue.indexOf(imgId);
					if(index < 0) {
						pictureUploader.delFromImg(imgId);
					} else {
						pictureUploader.delFromStorage(imgId, storageValue);
						pictureUploader.delFromImg(imgId);
					}
				}
			}
		}, "删除图片", bts);

	};

	pictureUploader.delFromImg = function(imgId) {
		//    	 alert(imgId);
		var toRemove = document.querySelector("#" + imgId);
		toRemove.parentNode.removeChild(toRemove);
	};

	pictureUploader.delFromStorage = function(imgId, storageValue) {

		// var wa = plus.nativeUI.showWaiting();
		var imgList = JSON.parse(storageValue);

		// console.log("删除前：" + imgList.length);
		for(var i = 0; i < imgList.length; i++) {
			var img = imgList[i];
			// console.log(JSON.stringify(img));
			if(img.fileName == imgId) {
				imgList.splice(i, 1);
				break;
			}
		}
		// console.log("删除后：" + imgList.length);
		plus.storage.setItem(pictureUploader.storageKey, JSON.stringify(imgList));
		// wa.close();
	};

	/**
	 * 上传图片
	 * @param agree
	 * @param back
	 */
	pictureUploader.upload = function(successCallback, failureCallback) {

		var storageValue = plus.storage.getItem(pictureUploader.storageKey);
		// console.log(storageValue);
		if(!storageValue || storageValue.length < 5) {
			if(pictureUploader.required == false) {
				if(successCallback)
					successCallback([]);
				return true;
			}
			plus.nativeUI.alert("请先选择图片", null, "提示信息");
			return false;
		}

		var wa = plus.nativeUI.showWaiting();

		var url = pictureUploader.uploadUrl;
		url += "?module=" + pictureUploader.uploadModule;
		url += "&ownId=" + pictureUploader.ownId || 0;
		if(pictureUploader.isAddressWatermark && pictureUploader.watermark) {
			url += "&watermarkText=" + pictureUploader.watermark;
		}
		url = encodeURI(url);
		//      console.log("图片上传地址：" + url);

		var task = plus.uploader.createUpload(url, {
				method: "POST",
				timeout: 10000
			},
			function(result, status, error) {
				wa.close();

				if(status === 200) {
					var data = JSON.parse(result.responseText);
					if(data && data.success) {

						if(successCallback) {
							successCallback(data, pictureUploader.ownId);
						}
					} else {
						if(failureCallback) {
							failureCallback(data);
						}
					}
					pictureUploader.clear();
					// task.clear();
				} else {
					plus.nativeUI.alert("网络错误:" + status, null, "图片上传失败");
				}
			}
		);

		var imgList = JSON.parse(storageValue);
		var imgUrl;
		for(var i = 0; i < imgList.length; i++) {
			imgUrl = imgList[i].url;
			if(!imgUrl) continue;
			task.addFile(imgUrl, {
				key: imgList[i].fileName
			});
			// console.log("添加上传任务：" + imgUrl);
		}

		task.start();

	};

	pictureUploader.init();
	return pictureUploader;
}